SORIWebAuthOptions class

Constructors

SORIWebAuthOptions.ephemeralKeyEndpoint(Uri ephemeralKeyEndpoint, {String requestMethod = 'POST', Map<String, String> requestHeaders = const <String, String>{}, SORIWebRequestCredentials requestCredentials = SORIWebRequestCredentials.sameOrigin, Uri? apiEndpoint, Uri? authEndpoint, Uri? activityEndpoint})
const

Properties

activityEndpoint Uri?
final
apiEndpoint Uri?
final
authEndpoint Uri?
final
ephemeralKeyEndpoint Uri
An application-server endpoint that returns ephemeralKey or ephemeral_key as JSON.
final
hashCode int
The hash code for this object.
no setterinherited
requestCredentials SORIWebRequestCredentials
final
requestHeaders Map<String, String>
final
requestMethod String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited