SORICampaign class
Constructors
- SORICampaign({required String id, required String name, String? description, String? imageUrl, String? actionUrl, int? createdAt, String? materialId, SORIActivityTrait? trait})
-
const
-
SORICampaign.fromMap(Map<
String, Object?> map) -
factory
Properties
- actionUrl → String?
-
final
- createdAt → int?
-
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- imageUrl → String?
-
final
- materialId → String?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trait → SORIActivityTrait?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited