SORIRecognitionConfig class
Constructors
- SORIRecognitionConfig({bool enableDelayedSending = true, int maxPendingTimeMillis = 10 * 60 * 1000, bool autoRetryOnNetworkRecovery = true})
-
const
Properties
- autoRetryOnNetworkRecovery → bool
-
final
- enableDelayedSending → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxPendingTimeMillis → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited