SORIRecognitionEvent class

Constructors

SORIRecognitionEvent({required SORIRecognitionEventType type, Map<String, Object?> payload = const <String, Object?>{}, SORICampaign? campaign, SORIActivityTrait? trait, int? code, String? message})
const
SORIRecognitionEvent.fromMap(Map<String, Object?> map)
factory

Properties

audioMarker String?
Latest marker code carried by either a marker-only event or a campaign hit.
no setter
campaign SORICampaign?
final
code int?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
payload Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trait SORIActivityTrait?
final
type SORIRecognitionEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited